@@ -21,9 +21,9 @@
 //! 
 //! Every loader returns a `CacheError` with an inner error.
 
-use std::collections::HashMap;
+use std::collections::{ hash_map, HashMap };
 
-use crate::{ Store, Loader, util, Cache };
+use crate::{ Store, Loader, Cache };
 
 use crate::def::osrs::{
     ItemDefinition,
@@ -34,21 +34,21 @@ use crate::def::osrs::{
 /// Loads all item definitions from the current cache.
 #[derive(Clone, Eq, PartialEq, Debug, Default)]
 pub struct ItemLoader {
-    pub items: HashMap<u16, ItemDefinition>
+    itms: HashMap<u32, ItemDefinition>
 }
 
 /// Loads all npc definitions from the current cache.
 #[derive(Clone, Eq, PartialEq, Debug, Default)]
 pub struct NpcLoader {
-    pub npcs: HashMap<u16, NpcDefinition>
+    npcs: HashMap<u32, NpcDefinition>
 }
 
 /// Loads all object definitions from the current cache.
 #[derive(Clone, Eq, PartialEq, Debug, Default)]
 pub struct ObjectLoader {
-    pub objs: HashMap<u16, ObjectDefinition>
+    objs: HashMap<u32, ObjectDefinition>
 }
 
-impl_osrs_loader!(ItemLoader, ItemDefinition, items, archive_id: 10);
-impl_osrs_loader!(NpcLoader, NpcDefinition, npcs, archive_id: 9);
-impl_osrs_loader!(ObjectLoader, ObjectDefinition, objs, archive_id: 6);
\ No newline at end of file
+impl_osrs_loader!(ItemLoader, ItemDefinition, itms, index_id: 2, archive_id: 10);
+impl_osrs_loader!(NpcLoader, NpcDefinition, npcs, index_id: 2, archive_id: 9);
+impl_osrs_loader!(ObjectLoader, ObjectDefinition, objs, index_id: 2, archive_id: 6);
\ No newline at end of file
